﻿Option Strict On
Option Explicit On

Imports ESRI.ArcGIS.ArcMapUI
Imports ESRI.ArcGIS.Carto
Imports ESRI.ArcGIS.Geodatabase
Imports ESRI.ArcGIS.esriSystem
Imports ESRI.ArcGIS.Framework
Imports ESRI.ArcGIS.Geometry
Imports ESRI.ArcGIS.Display
Imports System.Math
Public Class ECDrawExpressions
    Public Function feature_To_Graphic() As Long
        Try
            Dim pGeometry As IGeometry = params.Geometry
            If pGeometry.IsEmpty Then
                Return 0
            Else
                If pGeometry.GeometryType = ESRI.ArcGIS.Geometry.esriGeometryType.esriGeometryPoint Then
                    Dim pPoint As IPoint = CType(pGeometry, IPoint)
                    Return ET_DrawPointGraphic(pPoint)
                ElseIf pGeometry.GeometryType = ESRI.ArcGIS.Geometry.esriGeometryType.esriGeometryPolyline Then
                    Dim pPolyline As IPolyline = CType(pGeometry, IPolyline)
                    Return ET_DrawPolylineGraphic(pPolyline)
                ElseIf pGeometry.GeometryType = ESRI.ArcGIS.Geometry.esriGeometryType.esriGeometryPolygon Then
                    Dim pPolygon As IPolygon = CType(pGeometry, IPolygon)
                    Return ET_DrawPolygonGraphic(pPolygon)
                Else
                    Return 0
                End If
            End If
        Catch
            Return 0
        End Try
    End Function
    Public Function draw_Bounding_Rectangle() As Long
        Try
            Dim pGeometry As IGeometry = params.Geometry
            If pGeometry.IsEmpty Then
                Return 0
            Else
                If pGeometry.GeometryType = ESRI.ArcGIS.Geometry.esriGeometryType.esriGeometryPoint Then
                    Return 0
                Else
                    Dim pEnv As IEnvelope = pGeometry.Envelope
                    If pEnv.IsEmpty Then
                        Return 0
                    Else
                        Dim pContainer As IGraphicsContainer = CType(My.Document.FocusMap, IGraphicsContainer)
                        Dim pElement As IElement = New RectangleElement
                        pElement.Geometry = pEnv
                        pContainer.AddElement(pElement, 0)
                        Return 1
                    End If
                End If
            End If
        Catch
            Return 0
        End Try
    End Function
    Public Function draw_ConvexHull() As Long
        Try
            Dim pGeometry As IGeometry = params.Geometry
            If pGeometry.IsEmpty Then
                Return 0
            Else
                If pGeometry.GeometryType = ESRI.ArcGIS.Geometry.esriGeometryType.esriGeometryPoint Then
                    Return 0
                Else
                    Dim pTopOp As ITopologicalOperator = CType(pGeometry, ITopologicalOperator)
                    Dim pConvex As IPolygon = CType(pTopOp.ConvexHull, IPolygon)
                    Return ET_DrawPolygonGraphic(pConvex)
                End If
            End If
        Catch
            Return 0
        End Try
    End Function
    Public Function draw_Buffer() As Long
        Try
            Dim pGeometry As IGeometry = params.Geometry
            Dim pSrefMap As ISpatialReference = params.MapSref
            Dim pSrefData As ISpatialReference = params.DataSref
            Dim bDataSref As Boolean = params.SrefFromData
            Dim dBufferDistance As Double = CDbl(params.Par1)
            'if the spatial reference of the map is to be used
            'check whether the data can be projected
            'Only basic check performed below (if one of the spatial references is unknown the data cannot be projected).
            'TO DO - check whether the two spatial references have the same GCS
            If Not bDataSref Then
                If TypeOf pSrefMap Is IUnknownCoordinateSystem Or TypeOf pSrefData Is IUnknownCoordinateSystem Then
                    bDataSref = True
                End If
            End If
            If pGeometry.IsEmpty Then
                Return 0
            Else
                'If the Map spatial refernce is to be used - project the data
                If Not bDataSref Then
                    pGeometry.SpatialReference = pSrefData
                    pGeometry.Project(pSrefMap)
                End If
                Dim pTopOp As ITopologicalOperator = CType(pGeometry, ITopologicalOperator)
                Dim pBuffer As IPolygon = CType(pTopOp.Buffer(dBufferDistance), IPolygon)
                Return ET_DrawPolygonGraphic(pBuffer)
            End If
        Catch
            MsgBox(Err.Description)
            Return 0
        End Try
    End Function
    Public Function draw_Vertices() As Long
        Try
            Dim pGeometry As IGeometry = params.Geometry
            Dim i As Integer
            Dim pPoint As IPoint
            If pGeometry.IsEmpty Then
                Return 0
            Else
                If pGeometry.GeometryType = ESRI.ArcGIS.Geometry.esriGeometryType.esriGeometryPoint  Then
                    Return 0
                End If
                Dim pColl As IPointCollection = CType(pGeometry, IPointCollection)
                For i = 0 To pColl.PointCount - 1
                    pPoint = pColl.Point(i)
                    ET_DrawPointGraphic(pPoint)
                Next
            End If
        Catch
            Return 0
        End Try
    End Function
End Class
